==> vtk6-6.3.0-2-arm.pkg.tar.xz: vtk/vtkTemporalShiftScale.java <==
// java wrapper for vtkTemporalShiftScale object
//

package vtk;
import vtk.*;

public class vtkTemporalShiftScale extends vtkAlgorithm
{

  private native String GetClassName_0();
  public String GetClassName()
    { return GetClassName_0(); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native void SetPreShift_2(double id0);
  public void SetPreShift(double id0)
    { SetPreShift_2(id0); }

  private native double GetPreShift_3();
  public double GetPreShift()
    { return GetPreShift_3(); }

  private native void SetPostShift_4(double id0);
  public void SetPostShift(double id0)
    { SetPostShift_4(id0); }

  private native double GetPostShift_5();
  public double GetPostShift()
    { return GetPostShift_5(); }

  private native void SetScale_6(double id0);
  public void SetScale(double id0)
    { SetScale_6(id0); }

  private native double GetScale_7();
  public double GetScale()
    { return GetScale_7(); }

  private native void SetPeriodic_8(int id0);
  public void SetPeriodic(int id0)
    { SetPeriodic_8(id0); }

  private native int GetPeriodic_9();
  public int GetPeriodic()
    { return GetPeriodic_9(); }

  private native void PeriodicOn_10();
  public void PeriodicOn()
    { PeriodicOn_10(); }

  private native void PeriodicOff_11();
  public void PeriodicOff()
    { PeriodicOff_11(); }

  private native void SetPeriodicEndCorrection_12(int id0);
  public void SetPeriodicEndCorrection(int id0)
    { SetPeriodicEndCorrection_12(id0); }

  private native int GetPeriodicEndCorrection_13();
  public int GetPeriodicEndCorrection()
    { return GetPeriodicEndCorrection_13(); }

  private native void PeriodicEndCorrectionOn_14();
  public void PeriodicEndCorrectionOn()
    { PeriodicEndCorrectionOn_14(); }

  private native void PeriodicEndCorrectionOff_15();
  public void PeriodicEndCorrectionOff()
    { PeriodicEndCorrectionOff_15(); }

  private native void SetMaximumNumberOfPeriods_16(double id0);
  public void SetMaximumNumberOfPeriods(double id0)
    { SetMaximumNumberOfPeriods_16(id0); }

  private native double GetMaximumNumberOfPeriods_17();
  public double GetMaximumNumberOfPeriods()
    { return GetMaximumNumberOfPeriods_17(); }

  public vtkTemporalShiftScale() { super(); }

  public vtkTemporalShiftScale(long id) { super(id); }
  public native long   VTKInit();

}

==> vtk-8.2.0-3-arm.pkg.tar.xz: vtk/vtkTemporalShiftScale.java <==
// java wrapper for vtkTemporalShiftScale object
//

package vtk;
import vtk.*;

public class vtkTemporalShiftScale extends vtkAlgorithm
{

  private native int IsTypeOf_0(String id0);
  public int IsTypeOf(String id0)
    { return IsTypeOf_0(id0); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native void SetPreShift_2(double id0);
  public void SetPreShift(double id0)
    { SetPreShift_2(id0); }

  private native double GetPreShift_3();
  public double GetPreShift()
    { return GetPreShift_3(); }

  private native void SetPostShift_4(double id0);
  public void SetPostShift(double id0)
    { SetPostShift_4(id0); }

  private native double GetPostShift_5();
  public double GetPostShift()
    { return GetPostShift_5(); }

  private native void SetScale_6(double id0);
  public void SetScale(double id0)
    { SetScale_6(id0); }

  private native double GetScale_7();
  public double GetScale()
    { return GetScale_7(); }

  private native void SetPeriodic_8(int id0);
  public void SetPeriodic(int id0)
    { SetPeriodic_8(id0); }

  private native int GetPeriodic_9();
  public int GetPeriodic()
    { return GetPeriodic_9(); }

  private native void PeriodicOn_10();
  public void PeriodicOn()
    { PeriodicOn_10(); }

  private native void PeriodicOff_11();
  public void PeriodicOff()
    { PeriodicOff_11(); }

  private native void SetPeriodicEndCorrection_12(int id0);
  public void SetPeriodicEndCorrection(int id0)
    { SetPeriodicEndCorrection_12(id0); }

  private native int GetPeriodicEndCorrection_13();
  public int GetPeriodicEndCorrection()
    { return GetPeriodicEndCorrection_13(); }

  private native void PeriodicEndCorrectionOn_14();
  public void PeriodicEndCorrectionOn()
    { PeriodicEndCorrectionOn_14(); }

  private native void PeriodicEndCorrectionOff_15();
  public void PeriodicEndCorrectionOff()
    { PeriodicEndCorrectionOff_15(); }

  private native void SetMaximumNumberOfPeriods_16(double id0);
  public void SetMaximumNumberOfPeriods(double id0)
    { SetMaximumNumberOfPeriods_16(id0); }

  private native double GetMaximumNumberOfPeriods_17();
  public double GetMaximumNumberOfPeriods()
    { return GetMaximumNumberOfPeriods_17(); }

  public vtkTemporalShiftScale() { super(); }

  public vtkTemporalShiftScale(long id) { super(id); }
  public native long   VTKInit();

}
